import os
import re
from setuptools import find_namespace_packages, setup

package_version = os.environ.get("VERSION", "0.0.0.dev0")

if not re.match(r"\d+\.\d+\.\d(\..*)?", package_version):
    package_version = "0.0.0-dev"
with open("README.md", "r", encoding="utf-8") as readme:
    long_description = readme.read()

title = "onec-checkgrammar"
author = "a.krapivin"
email = "krapivin_andrey@mail.ru"
url = "https://github.com/kontur-1c/onec-grammarcheck"

requires = ["pyaspeller", "Click", "junit-xml", "wasabi", "tqdm"]
requires_test = ["pytest", "pytest-cov", "pytest-runner", "pytest-click"]
requires_dev = requires_test + ["black", "flake8"]

setup(
    name=title,
    version=package_version,
    description="Проверка орфографии элементов формы для 1с",
    long_description=long_description,
    long_description_content_type="text/markdown",
    python_requires=">=3.6",
    install_requires=requires,
    setup_requires=requires_dev,
    tests_require=requires_test,
    url=url,
    packages=find_namespace_packages(include=["kontur.*"]),
    entry_points={
        "console_scripts": ["onec-checkgrammar=kontur.checkgrammar.cli:cli"]
    },
    include_package_data=True,
    author=author,
    author_email=email,
    maintainer=author,
    maintainer_email=email,
    classifiers=[
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Operating System :: OS Independent",
    ],
)



import sys

import click

from kontur.checkgrammar.grammar import GrammarCheck


@click.command()
@click.argument("src", envvar="SRC", nargs=-1)
@click.option(
    "-d",
    "--dict",
    "dictionary",
    default=None,
    multiple=True,
    help="Словари исключений из проверки",
)
@click.option(
    "-bsl",
    "--bsl-settings",
    "bsl",
    is_flag=False,
    flag_value=".bsl-language-server.json",
    help="Получить словарь из настроек bsl-language-server.json",
)
@click.option("--dry-run", "dry_run", is_flag=True, help="Не ронять тесты")
@click.option("--junit", "junit", default=None, help="Файл отчета в формате junit")
@click.option("--output", "output", default=None, help="Файл для ошибок")
def cli(src, dictionary, bsl, junit, output, dry_run):
    """Проверка орфографии элементов форм в каталоге SRC.

    SRC каталог исходников конфигурации или внешней обработки/отчета.

    Можно указать несколько через пробел"""

    check = GrammarCheck()
    for d in dictionary:
        check.update_dict_from_file(d)

    if bsl:
        check.update_dict_from_bsl(bsl)

    for s in src:
        check.add_src(s)

    check.run()

    if junit is not None:
        check.dump_junit(junit)

    if output is not None:
        check.dump_dict(output)

    if check.has_errors:
        print("Обнаружены ошибки", file=sys.stderr)
        check.print()
        if not dry_run:
            sys.exit(1)
    else:
        print("Нет ошибок", file=sys.stdout)
        sys.exit(0)
